@@ -230,9 +230,8 @@ class Sheet(Epithelium):
         """
 
         datasets = {}
-
-        datasets['face'] = self.face_df[
-            self.face_df[face_mask]].copy()
+        mask = self.face_df[face_mask].astype(bool)
+        datasets['face'] = self.face_df[mask].copy()
         datasets['edge'] = self.edge_df[self.edge_df['face'].isin(
             datasets['face'].index)].copy()
         datasets['vert'] = self.vert_df.loc[self.edge_df['srce'].unique()].copy()
@@ -286,12 +285,12 @@ class Sheet(Epithelium):
         datasets['edge'] = self.edge_df[self.edge_df['face'].isin(
             datasets['face'].index)].copy()
 
-        datasets['vert'] = self.vert_df.loc[self.edge_df['srce'].unique()]
+        datasets['vert'] = self.vert_df.loc[self.edge_df['srce'].unique()].copy()
 
         subsheet = Sheet('subsheet', datasets, self.specs)
         subsheet.reset_index()
         subsheet.reset_topo()
-        return (subsheet)
+        return subsheet
 
     @classmethod
     def planar_sheet_2d(cls, identifier,
@@ -366,7 +365,7 @@ def get_opposite(edge_df):
     flipped = st_indexed.index.swaplevel(0, 1)
     flipped.names = ['srce', 'trgt']
 
-    opposite = st_indexed.loc[flipped, 'edge'].values
+    opposite = st_indexed.reindex(flipped)['edge'].values
     opposite[np.isnan(opposite)] = -1
 
     return opposite.astype(np.int)
